@@ -7,8 +7,8 @@
 ##  - skip_admember
 
 import contextlib
+from collections.abc import Generator
 from dataclasses import dataclass
-from typing import Generator, List, Optional, Tuple
 
 import pytest
 
@@ -30,11 +30,11 @@ AD = ADConnection()
 @dataclass
 class SubTree:
     name: str
-    udm_position: Optional[str] = None
-    ad_position: Optional[str] = None
-    udm_dn: Optional[str] = None
-    ad_dn: Optional[str] = None
-    objects: Optional[List] = None
+    udm_position: str | None = None
+    ad_position: str | None = None
+    udm_dn: str | None = None
+    ad_dn: str | None = None
+    objects: str | None = None
 
 
 @dataclass
@@ -45,8 +45,8 @@ class DomObject:
     udm_rdn: str
     udm_position: str
     udm_module: str
-    old_udm_position: Optional[str] = None
-    old_ad_position: Optional[str] = None
+    old_udm_position: str | None = None
+    old_ad_position: str | None = None
 
     @property
     def ad_dn(self):
@@ -68,10 +68,9 @@ class DomObject:
 @contextlib.contextmanager
 def allow_subtree_setup(
     sync_mode: str,
-    allow_subtree_ancestors: bool = False,
     pre_create_objects: bool = False,
     only_ucs: bool = False,
-) -> Generator[Tuple[List, List, UCSTestUDM], None, None]:
+) -> Generator[tuple[list, list, UCSTestUDM], None, None]:
     with UCSTestUDM() as udm:
         try:
             with testing_ucr.UCSTestConfigRegistry() as ucr:
@@ -95,39 +94,28 @@ def allow_subtree_setup(
                 not_allowed1.ad_dn = f'ou={not_allowed1.name},{not_allowed1.ad_position}'
 
                 allowed2 = SubTree(name='ou2-allowed')
-                # position below not explicitly allowed OU
-                allowed2.udm_position = not_allowed1.udm_dn
-                # position below not explicitly allowed OU
-                allowed2.ad_position = not_allowed1.ad_dn
+                allowed2.udm_position = not_allowed1.udm_dn  # position below not explicitly allowed OU
+                allowed2.ad_position = not_allowed1.ad_dn    # position below not explicitly allowed OU
                 allowed2.udm_dn = f'ou={allowed2.name},{allowed2.udm_position}'
                 allowed2.ad_dn = f'ou={allowed2.name},{allowed2.ad_position}'
 
-                # test not allowing the standard cn=users container
-                not_allowed2 = SubTree(name='users')
+                not_allowed2 = SubTree(name='users')        # test not allowing the standard cn=users container
                 not_allowed2.udm_position = ucr['ldap/base']
                 not_allowed2.ad_position = ucr['connector/ad/ldap/base']
                 not_allowed2.udm_dn = f'cn={not_allowed2.name},{not_allowed2.udm_position}'
                 not_allowed2.ad_dn = f'cn={not_allowed2.name},{not_allowed2.ad_position}'
 
                 not_allowed3 = SubTree(name='ou3')
-                # position below explicitly allowed OU
-                not_allowed3.udm_position = allowed2.udm_dn
-                # position below explicitly allowed OU
-                not_allowed3.ad_position = allowed2.ad_dn
+                not_allowed3.udm_position = allowed2.udm_dn  # position below explicitly allowed OU
+                not_allowed3.ad_position = allowed2.ad_dn    # position below explicitly allowed OU
                 not_allowed3.udm_dn = f'ou={not_allowed3.name},{not_allowed3.udm_position}'
                 not_allowed3.ad_dn = f'ou={not_allowed3.name},{not_allowed3.ad_position}'
-
-                if allow_subtree_ancestors:
-                    ucr.handler_set(['connector/ad/mapping/allow-subtree-ancestors=yes'])
-                else:
-                    ucr.handler_set(['connector/ad/mapping/allow-subtree-ancestors=no'])
-
                 # create container and optionally some objects in the containers
                 if ucr['connector/ad/mapping/syncmode'] not in ('sync', 'write'):
                     # configure connector for sync
                     ucr_set(
                         [
-                            'connector/ad/mapping/syncmode=sync',
+                            "connector/ad/mapping/syncmode=sync",
                         ],
                     )
                     restart_adconnector()
@@ -151,13 +139,13 @@ def allow_subtree_setup(
                 # configure connector
                 ucr_set(
                     [
-                        f'connector/ad/mapping/allowsubtree/test1/ucs={allowed1.udm_dn}',
-                        f'connector/ad/mapping/allowsubtree/test1/ad={allowed1.ad_dn}',
-                        f'connector/ad/mapping/allowsubtree/test2/ucs={allowed2.udm_dn}',
-                        f'connector/ad/mapping/allowsubtree/test2/ad={allowed2.ad_dn}',
-                        f'connector/ad/mapping/ignoresubtree/test3-ucs={not_allowed3.udm_dn}',
-                        f'connector/ad/mapping/ignoresubtree/test3-ad={not_allowed3.ad_dn}',
-                        f'connector/ad/mapping/syncmode={sync_mode}',
+                        f"connector/ad/mapping/allowsubtree/test1/ucs={allowed1.udm_dn}",
+                        f"connector/ad/mapping/allowsubtree/test1/ad={allowed1.ad_dn}",
+                        f"connector/ad/mapping/allowsubtree/test2/ucs={allowed2.udm_dn}",
+                        f"connector/ad/mapping/allowsubtree/test2/ad={allowed2.ad_dn}",
+                        f"connector/ad/mapping/ignoresubtree/test3-ucs={not_allowed3.udm_dn}",
+                        f"connector/ad/mapping/ignoresubtree/test3-ad={not_allowed3.ad_dn}",
+                        f"connector/ad/mapping/syncmode={sync_mode}",
                     ],
                 )
                 restart_adconnector()
@@ -167,7 +155,7 @@ def allow_subtree_setup(
     wait_for_sync()
 
 
-def create_objects_in_ucs(udm: UCSTestUDM, tree: SubTree, wait: bool = True) -> List[DomObject]:
+def create_objects_in_ucs(udm: UCSTestUDM, tree: SubTree, wait: bool = True) -> [DomObject]:
     objects = []
     _, username = udm.create_user(position=tree.udm_dn)
     objects.append(
@@ -178,7 +166,7 @@ def create_objects_in_ucs(udm: UCSTestUDM, tree: SubTree, wait: bool = True) ->
             udm_rdn=f'uid={username}',
             udm_position=tree.udm_dn,
             udm_module='users/user',
-        )
+        ),
     )
     # TODO group
     if wait:
@@ -186,7 +174,7 @@ def create_objects_in_ucs(udm: UCSTestUDM, tree: SubTree, wait: bool = True) ->
     return objects
 
 
-def create_objects_in_ad(ad: ADConnection, tree: SubTree, wait: bool = True) -> List[DomObject]:
+def create_objects_in_ad(ad: ADConnection, tree: SubTree, wait: bool = True) -> [DomObject]:
     objects = []
     username = random_string()
     ad.createuser(username, position=tree.ad_dn)
@@ -197,8 +185,8 @@ def create_objects_in_ad(ad: ADConnection, tree: SubTree, wait: bool = True) ->
             ad_position=tree.ad_dn,
             udm_rdn=f'uid={username}',
             udm_position=tree.udm_dn,
-            udm_module='users/user'
-        )
+            udm_module='users/user',
+        ),
     )
     # TODO group
     if wait:
@@ -223,11 +211,10 @@ def move_to_subtree_in_ad(ad: ADConnection, obj: DomObject, tree: SubTree) -> No
 
 
 # @pytest.mark.parametrize("sync_mode", ["read", "sync"])
-@pytest.mark.parametrize('sync_mode', ['sync'])
-@pytest.mark.parametrize('allow_subtree_ancestors', [True, False])
-@pytest.mark.skipif(not connector_running_on_this_host(), reason='Univention AD Connector not configured.')
-def test_create(sync_mode: str, allow_subtree_ancestors: bool) -> None:
-    with allow_subtree_setup(sync_mode, allow_subtree_ancestors=allow_subtree_ancestors) as (allowed, denied, udm):
+@pytest.mark.parametrize("sync_mode", ["sync"])
+@pytest.mark.skipif(not connector_running_on_this_host(), reason="Univention AD Connector not configured.")
+def test_create(sync_mode: str) -> None:
+    with allow_subtree_setup(sync_mode) as (allowed, denied, udm):
         # check denied for other subtrees
         for tree in denied:
             if sync_mode in ('sync', 'write'):
@@ -254,11 +241,10 @@ def test_create(sync_mode: str, allow_subtree_ancestors: bool) -> None:
 
 
 # @pytest.mark.parametrize("sync_mode", ["read", "sync"])
-@pytest.mark.parametrize('sync_mode', ['sync'])
-@pytest.mark.parametrize('allow_subtree_ancestors', [True, False])
-@pytest.mark.skipif(not connector_running_on_this_host(), reason='Univention AD Connector not configured.')
-def test_modify(sync_mode: str, allow_subtree_ancestors: bool) -> None:
-    with allow_subtree_setup(sync_mode, allow_subtree_ancestors=allow_subtree_ancestors, pre_create_objects=True) as (allowed, denied, udm):
+@pytest.mark.parametrize("sync_mode", ["sync"])
+@pytest.mark.skipif(not connector_running_on_this_host(), reason="Univention AD Connector not configured.")
+def test_modify(sync_mode: str) -> None:
+    with allow_subtree_setup(sync_mode, pre_create_objects=True) as (allowed, denied, udm):
         for tree in denied:
             if sync_mode in ('sync', 'write'):
                 for obj in tree.objects:
@@ -271,7 +257,7 @@ def test_modify(sync_mode: str, allow_subtree_ancestors: bool) -> None:
             if sync_mode in ('sync', 'read'):
                 for obj in tree.objects:
                     # modify in AD, check no change in UCS
-                    AD.set_attribute(obj.ad_dn, 'description', 'changed in AD'.encode('UTF-8'))
+                    AD.set_attribute(obj.ad_dn, 'description', b'changed in AD')
                     AD.verify_object(obj.ad_dn, {'description': 'changed in AD'})
                     wait_for_sync()
                     with pytest.raises(LDAPObjectValueMissing):
@@ -288,18 +274,17 @@ def test_modify(sync_mode: str, allow_subtree_ancestors: bool) -> None:
             if sync_mode in ('sync', 'read'):
                 for obj in tree.objects:
                     # modify in AD, check cange in UCS
-                    AD.set_attribute(obj.ad_dn, 'description', 'changed in AD'.encode('UTF-8'))
+                    AD.set_attribute(obj.ad_dn, 'description', b'changed in AD')
                     AD.verify_object(obj.ad_dn, {'description': 'changed in AD'})
                     wait_for_sync()
                     udm.verify_ldap_object(obj.udm_dn, expected_attr={'description': ['changed in AD']})
 
 
 # @pytest.mark.parametrize("sync_mode", ["read", "sync"])
-@pytest.mark.parametrize('sync_mode', ['sync'])
-@pytest.mark.parametrize('allow_subtree_ancestors', [True, False])
-@pytest.mark.skipif(not connector_running_on_this_host(), reason='Univention AD Connector not configured.')
-def test_move_into_allowed_subtree(sync_mode: str, allow_subtree_ancestors: bool) -> None:
-    with allow_subtree_setup(sync_mode, allow_subtree_ancestors=allow_subtree_ancestors) as (allowed, denied, udm):
+@pytest.mark.parametrize("sync_mode", ["sync"])
+@pytest.mark.skipif(not connector_running_on_this_host(), reason="Univention AD Connector not configured.")
+def test_move_into_allowed_subtree(sync_mode: str) -> None:
+    with allow_subtree_setup(sync_mode) as (allowed, denied, udm):
         # create objects in denied subtree in UCS/AD
         # and move to allowed subtree, check object is created
         allowed_subtree = allowed[0]
@@ -331,11 +316,10 @@ def test_move_into_allowed_subtree(sync_mode: str, allow_subtree_ancestors: bool
 
 
 # @pytest.mark.parametrize("sync_mode", ["read", "sync", "write"])
-@pytest.mark.parametrize('sync_mode', ['sync'])
-@pytest.mark.parametrize('allow_subtree_ancestors', [True, False])
-@pytest.mark.skipif(not connector_running_on_this_host(), reason='Univention AD Connector not configured.')
-def test_move_out_of_allowed_subtree(sync_mode: str, allow_subtree_ancestors: bool) -> None:
-    with allow_subtree_setup(sync_mode, allow_subtree_ancestors=allow_subtree_ancestors) as (allowed, denied, udm):
+@pytest.mark.parametrize("sync_mode", ["sync"])
+@pytest.mark.skipif(not connector_running_on_this_host(), reason="Univention AD Connector not configured.")
+def test_move_out_of_allowed_subtree(sync_mode: str) -> None:
+    with allow_subtree_setup(sync_mode) as (allowed, denied, udm):
         # create object in allowed subtree in UCS/AD
         # move out of allowed subtree and check that object is removed
         allowed_subtree = allowed[0]
@@ -368,11 +352,10 @@ def test_move_out_of_allowed_subtree(sync_mode: str, allow_subtree_ancestors: bo
                     udm.verify_ldap_object(obj.old_udm_dn, retry_count=3, delay=1)
 
 
-@pytest.mark.parametrize('sync_mode', ['sync'])
-@pytest.mark.parametrize('allow_subtree_ancestors', [True, False])
-@pytest.mark.skipif(not connector_running_on_this_host(), reason='Univention AD Connector not configured.')
-def test_ignored_object_is_not_moved(sync_mode: str, allow_subtree_ancestors: bool, ucr) -> None:
-    with allow_subtree_setup(sync_mode, allow_subtree_ancestors=allow_subtree_ancestors, pre_create_objects=True) as (allowed, _denied, udm):  # noqa: F841
+@pytest.mark.parametrize("sync_mode", ["sync"])
+@pytest.mark.skipif(not connector_running_on_this_host(), reason="Univention AD Connector not configured.")
+def test_ignored_object_is_not_moved(sync_mode: str, ucr) -> None:
+    with allow_subtree_setup(sync_mode, pre_create_objects=True) as (allowed, denied, udm):  # noqa: F841
         username = allowed[0].objects[0].name
         udm_dn = allowed[0].objects[0].udm_dn
         ad_dn = allowed[0].objects[0].ad_dn
@@ -389,11 +372,10 @@ def test_ignored_object_is_not_moved(sync_mode: str, allow_subtree_ancestors: bo
         delete_con_user(AD, ad_dn, udm_dn, wait_for_sync)
 
 
-@pytest.mark.parametrize('sync_mode', ['sync'])
-@pytest.mark.parametrize('allow_subtree_ancestors', [True, False])
-@pytest.mark.skipif(not connector_running_on_this_host(), reason='Univention AD Connector not configured.')
-def test_ignored_object_is_not_removed(sync_mode: str, allow_subtree_ancestors: bool, ucr) -> None:
-    with allow_subtree_setup(sync_mode, allow_subtree_ancestors=allow_subtree_ancestors, pre_create_objects=True) as (allowed, _denied, udm):  # noqa: F841
+@pytest.mark.parametrize("sync_mode", ["sync"])
+@pytest.mark.skipif(not connector_running_on_this_host(), reason="Univention AD Connector not configured.")
+def test_ignored_object_is_not_removed(sync_mode: str, ucr) -> None:
+    with allow_subtree_setup(sync_mode, pre_create_objects=True) as (allowed, denied, udm):  # noqa: F841
         username = allowed[0].objects[0].name
         udm_dn = allowed[0].objects[0].udm_dn
         ad_dn = allowed[0].objects[0].ad_dn
