@@ -7,10 +7,11 @@ import socket
 import subprocess
 import time
 from html import unescape
+from urllib.parse import urlparse
 
 import requests
 from bs4 import BeautifulSoup
-from lxml import etree  # noqa: S410
+from lxml import etree
 from requests_kerberos import OPTIONAL, HTTPKerberosAuth
 
 import univention.config_registry as configRegistry
@@ -24,14 +25,13 @@ class SamlError(Exception):
 def errors():
     return {
         'The password has expired and must be renewed.': SamlPasswordExpired,
-        'Account expired.': SamlAccountExpired,  # simplesamlphp
-        'The account has expired.': SamlAccountExpired,  # keycloak
-        'Invalid username or password.': SamlAuthenticationFailed,  # keycloak
-        'Incorrect username or password.': SamlAuthenticationFailed,  # simplesamlphp
-        'Account not verified.': SamlAccountNotVerified,
-        'Changing password failed.': SamlPasswordChangeFailed,  # simplesamlphp
-        'Changing password failed. The password was already used.': SamlPasswordChangeFailed,  # keycloak
+        'The account has expired.': SamlAccountExpired,
+        'Invalid username or password.': SamlAuthenticationFailed,
+        'Your account is not verified.': SamlAccountNotVerified,
+        'Changing password failed. The password was already used.': SamlPasswordChangeFailed,
+        'Changing password failed. The password is too simple.': SamlPasswordChangeFailed,
         'The password has been changed successfully.': SamlPasswordChangeSuccess,
+        'Das Passwort wurde erfolgreich geändert.': SamlPasswordChangeSuccess,
     }
 
 
@@ -46,11 +46,12 @@ class SamlLoginError(SamlError):
         super().__init__(message)
 
     def __new__(cls, saml, password_change=False):
-        # SSP: umcLoginNotices; Keycloak: kc-form/kc-passwd-update-form
-        if saml.keycloak and password_change:
+        if password_change:
             message = saml.xpath('*[@id="kc-content-wrapper"]/div/span')
         else:
-            message = saml.xpath('div[@id="umcLoginNotices"]') if not saml.keycloak else saml.xpath('*[@id="kc-form"]/div[1]/div/span', saml.xpath('form[@id="kc-passwd-update-form"]/div[@class="form-group"]/p'))
+            message = saml.xpath('*[@id="kc-form"]/div[1]/div/span', saml.xpath('form[@id="kc-passwd-update-form"]/div[@class="form-group"]/p'))
+        if message is None:
+            message = saml.xpath('*[@id="univention-self-service-form"]/div/div/p')
         if message is not None:
             message = message.text.strip()
         return Exception.__new__(errors().get(message, cls), saml, message)
@@ -85,7 +86,7 @@ class GuaranteedIdP:
         self.ip = ip
         ucr = configRegistry.ConfigRegistry()
         ucr.load()
-        self.sso_fqdn = ucr['ucs/server/sso/fqdn']
+        self.sso_fqdn = urlparse(ucr['ucs/server/sso/uri']).netloc
 
     def __enter__(self):
         subprocess.call(['ucr', 'set', 'hosts/static/%s=%s' % (self.ip, self.sso_fqdn)])
@@ -144,17 +145,13 @@ class SamlTest:
         self.parsed_page = None
         self.position = 'Init...'
 
-        url = 'https://%s/univention/saml/' % self.target_sp_hostname
-        res = self.session.request('POST', url)
-        self.keycloak = '/simplesamlphp' not in res.url
-
     def _check_status_code(self, status_code):
         # check for an expected status_code as a different would indicate an error
         # in the current login step.
         if self.page.status_code != status_code:
             raise SamlError("Problem while %s\nWrong status code: %s, expected: %s\nServer response was: %s" % (self.position, self.page.status_code, status_code, self.page.content.decode('UTF-8', 'replace')))
 
-    def _request(self, method, url, status_code, data=None, expected_format='html'):
+    def _request(self, method, url, status_code, data=None, expected_format='html', kerberos_redirect=False):
         """
         does POST or GET requests and raises SamlError which encodes the login step
         through position parameter.
@@ -167,7 +164,11 @@ class SamlTest:
             'GET': self.session.get,
             'POST': self.session.post}
         try:
-            self.page = _requests[method](url, data=data, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
+            res = _requests[method](url, data=data, verify='/etc/univention/ssl/ucsCA/CAcert.pem', headers=headers)
+            if res.status_code == 401 and status_code != 401 and kerberos_redirect:
+                res = self._follow_kerberos_redirect(res.content)
+            self.page = res
+
         except requests.exceptions.SSLError:
             # Bug: https://github.com/shazow/urllib3/issues/556
             # raise SamlError("Problem while %s\nSSL error: %s" % (self.position, exc))
@@ -192,12 +193,7 @@ class SamlTest:
         self.position = "posting login form"
         print("Post SAML login form to: %s" % self.page.url)
         data = {'username': self.username, 'password': self.password}
-        if not self.keycloak:  # SSP
-            auth_state = self._extract_auth_state()
-            data['AuthState'] = auth_state
-            login_link = self.page.url
-        else:
-            login_link = self._kerberos_login_link()
+        login_link = self._kerberos_login_link()
         self._request('POST', login_link, 200, data=data)
 
     def xpath(self, xpath, default=None):
@@ -365,16 +361,10 @@ class SamlTest:
                 self._request('GET', url, 200)
             except SamlError:
                 # The kerberos backend adds a manual redirect
-                if not self.keycloak:
-                    if not self.page or self.page.status_code != 401:
-                        raise
-                    login_link = re.search('<a href="([^"]+)">', bytes(self.page.text)).group(1)
-                    self._request('GET', login_link, 200)
-                else:
-                    soup = BeautifulSoup(self.page.content, 'html.parser')
-                    title = soup.find('title')
-                    if not (self.page.status_code == 401 and title and 'Kerberos' in title.text):
-                        raise
+                soup = BeautifulSoup(self.page.content, 'html.parser')
+                title = soup.find('title')
+                if not (self.page.status_code == 401 and title and 'Kerberos' in title.text):
+                    raise
 
             self._login_at_idp_with_credentials()
 
@@ -391,9 +381,6 @@ class SamlTest:
         self.position = "trying to logout"
         self._request('GET', url, 200)
 
-        if not self.keycloak:
-            return
-
         url = self._extract_sp_url()
         saml_msg = self.xpath('input[@name="SAMLResponse"]', {}).get('value')
         relay_state = self._extract_relay_state()
@@ -403,14 +390,9 @@ class SamlTest:
         self.position = "posting change password form"
         print("Post SAML change password form to: %s" % self.page.url)
 
-        if not self.keycloak:
-            auth_state = self._extract_auth_state()
-            data = {'username': self.username, 'password': self.password, 'AuthState': auth_state, 'new_password': new_password, 'new_password_retype': new_password}
-            self._request('POST', self.page.url, 200, data=data)
-        else:
-            data = {'username': self.username, 'password': self.password, 'password-new': new_password, 'password-confirm': new_password}
-            url = self._extract_sp_url()
-            self._request('POST', url, 200, data=data)
+        data = {'username': self.username, 'password': self.password, 'password-new': new_password, 'password-confirm': new_password}
+        url = self._extract_sp_url()
+        self._request('POST', url, 200, data=data, kerberos_redirect=True)
 
         self.password = new_password
         url = self._extract_sp_url()
