@@ -1,5 +1,4 @@
 #!/usr/share/ucs-test/runner /usr/share/ucs-test/playwright
-# -*- coding: utf-8 -*-
 ## desc: Test the 'Process overview' module
 ## packages:
 ##  - univention-management-console-module-top
@@ -11,7 +10,7 @@
 ## exposure: dangerous
 
 import subprocess
-from typing import Generator
+from collections.abc import Generator
 
 import pytest
 
