@@ -21,8 +21,7 @@ import time
 from contextlib import contextmanager
 from http.client import HTTPConnection
 from shlex import quote
-from types import TracebackType
-from typing import Callable, Dict, Iterator, List, Sequence, Type
+from typing import TYPE_CHECKING
 from urllib.parse import urlparse
 
 import requests
@@ -31,6 +30,11 @@ from selenium.webdriver.common.by import By
 from univention.testing import ucr as _ucr
 
 
+if TYPE_CHECKING:
+    from collections.abc import Callable, Iterator, Sequence
+    from types import TracebackType
+
+
 logger = logging.getLogger(__name__)
 PROVIDER_PORTAL_JSON = 'https://provider-portal.software-univention.de/appcenter-selfservice/univention-appcenter-catalog.json'
 
@@ -50,7 +54,7 @@ def run_test_file(fname: str) -> None:
 
 
 @contextmanager
-def pip_modules(modules: List[str]) -> Iterator[None]:
+def pip_modules(modules: list[str]) -> Iterator[None]:
     if os.environ.get('UCS_TEST_NO_PIP') == 'TRUE':
         yield
     if not shutil.which('pip3'):
@@ -67,13 +71,13 @@ def pip_modules(modules: List[str]) -> Iterator[None]:
     if modules:
         logger.info('Installing modules via pip3')
         logger.info('  {}'.format(' '.join(modules)))
-        subprocess.check_output(['pip3', 'install'] + modules)
+        subprocess.check_output(['pip3', 'install', *modules])
     try:
         yield
     finally:
         if modules:
             logger.info('Uninstalling modules via pip3')
-            subprocess.check_output(['pip3', 'uninstall', '--yes'] + modules)
+            subprocess.check_output(['pip3', 'uninstall', '--yes', *modules])
 
 
 @contextmanager
@@ -122,7 +126,7 @@ class Session:
     def __enter__(self):  # -> Session # Py3.9: Self
         yield self  # FIXME?
 
-    def __exit__(self, exc_type: Type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
+    def __exit__(self, exc_type: type[BaseException] | None, exc_value: BaseException | None, traceback: TracebackType | None) -> None:
         self.driver.quit()
 
     def __del__(self) -> None:
@@ -170,10 +174,7 @@ class Session:
                 time.sleep(3)
                 break
         else:
-            print('Could not find "Change Language" in portal sidemenu')
-            # close side menu
-            self.wait_until_clickable_and_click('#header-button-menu')
-            return
+            raise RuntimeError('Could not find "Change Language" in portal sidemenu')
         # choose english
         for elem in self.find_all('.portal-sidenavigation__menu-item--show'):
             print('sub -%s-' % elem.text)
@@ -182,7 +183,7 @@ class Session:
                 time.sleep(3)
                 break
         else:
-            print('Could not find "English" in portal sidemenu')
+            raise RuntimeError('Could not find "English" in portal sidemenu')
         # close side menu
         self.wait_until_clickable_and_click('#header-button-menu')
 
@@ -229,11 +230,11 @@ class Session:
     def reload(self) -> None:
         self.driver.refresh()
 
-    def find_all(self, css: str) -> List:
+    def find_all(self, css: str) -> list:
         logger.info("Searching for %r", css)
         return self.driver.find_elements(By.CSS_SELECTOR, css)
 
-    def find_all_below(self, element, css: str) -> List:
+    def find_all_below(self, element, css: str) -> list:
         return element.find_elements(By.CSS_SELECTOR, css)
 
     def find_first(self, css: str):
@@ -345,7 +346,7 @@ except ImportError:
     pass
 else:
     @pytest.fixture(scope='session')
-    def config() -> Dict[str, str]:
+    def config() -> dict[str, str]:
         """
         Test wide Configuration aka UCR
         Used to get some defaults if not environment variables are
@@ -432,7 +433,7 @@ else:
         class UCR:
             def __init__(self, client) -> None:
                 self.client = client
-                self._old: Dict[str, str] = {}
+                self._old: dict[str, str] = {}
 
             def get(self, key: str):
                 logger.info('Getting UCRV %s', key)
