@@ -51,7 +51,7 @@ def to_bytes(value):
 
 
 def get_first(value):
-    if isinstance(value, (list, tuple)):
+    if isinstance(value, list | tuple):
         return value[0]
     return value
 
@@ -188,7 +188,7 @@ class LDAPConnection:
 
     def set_attributes(self, dn, **attributes):
         old_attributes = self.get(dn, attr=attributes.keys())
-        attributes = {name: [attr] if not isinstance(attr, (list, tuple)) else attr for name, attr in attributes.items()}
+        attributes = {name: [attr] if not isinstance(attr, list | tuple) else attr for name, attr in attributes.items()}
         ldif = modlist.modifyModlist(old_attributes, attributes)
         comp_dn = dn
         if ldif:
@@ -198,10 +198,7 @@ class LDAPConnection:
     def set_attribute_with_provision_ctrl(self, dn, key, value):
         LDB_CONTROL_PROVISION_OID = '1.3.6.1.4.1.7165.4.3.16'
         DSDB_CONTROL_REPLICATED_UPDATE_OID = '1.3.6.1.4.1.7165.4.3.3'
-        ctrls = [
-            LDAPControl(LDB_CONTROL_PROVISION_OID, criticality=0),
-            LDAPControl(DSDB_CONTROL_REPLICATED_UPDATE_OID, criticality=0),
-        ] + self.serverctrls_for_add_and_modify
+        ctrls = [LDAPControl(LDB_CONTROL_PROVISION_OID, criticality=0), LDAPControl(DSDB_CONTROL_REPLICATED_UPDATE_OID, criticality=0), *self.serverctrls_for_add_and_modify]
         print(f'Replace {key!r}={value!r} at {dn!r} (with provision control)', file=sys.stderr)
         self.lo.modify_ext_s(dn, [(ldap.MOD_REPLACE, key, value)], serverctrls=ctrls)
 
@@ -316,7 +313,7 @@ class ADConnection(LDAPConnection):
         exploded = ldap.dn.str2dn(dn)
         new_rdn = [("cn", name, ldap.AVA_STRING)] if name else exploded[0]
         new_position = ldap.dn.str2dn(position) if position else exploded[1:]
-        new_dn = ldap.dn.dn2str([new_rdn] + new_position)
+        new_dn = ldap.dn.dn2str([new_rdn, *new_position])
         self.move(dn, new_dn)
         return new_dn
 
@@ -426,7 +423,7 @@ class ADConnection(LDAPConnection):
             ad_object = self.get(dn)
             for (key, value) in expected_attributes.items():
                 ad_value = {tcommon.to_unicode(x).lower() for x in ad_object.get(key, [])}
-                expected = set((tcommon.to_unicode(v).lower() for v in value) if isinstance(value, (list, tuple)) else (tcommon.to_unicode(value).lower(),))
+                expected = set((tcommon.to_unicode(v).lower() for v in value) if isinstance(value, list | tuple) else (tcommon.to_unicode(value).lower(),))
                 if not expected.issubset(ad_value):
                     try:
                         ad_value = {tcommon.normalize_dn(dn) for dn in ad_value}
