@@ -23,10 +23,14 @@ import sys
 import time
 import unicodedata
 from optparse import SUPPRESS_HELP, OptionGroup, OptionParser, Values
-from typing import Any, Dict, Iterable, Iterator, List, Literal, NoReturn, Set, Tuple
+from typing import TYPE_CHECKING, Any, Literal, NoReturn
 
 
-Entry = Dict[str, List[str]]
+if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator
+
+
+Entry = dict[str, list[str]]
 
 USAGE = 'usage: %prog [option] <LDIF1> [[option] <LDIF2>]'
 DESCRIPTION = '''
@@ -76,7 +80,7 @@ class Ldif:
         'structuralObjectClass',
     }
 
-    def __init__(self, src: Iterable[bytes], exclude: Set[str] = OPERATIONAL) -> None:
+    def __init__(self, src: Iterable[bytes], exclude: set[str] = OPERATIONAL) -> None:
         self.src = src
         self.exclude = exclude
         self.lno = 0
@@ -96,7 +100,7 @@ class Ldif:
 
         yield ''.join(lines)
 
-    def split(self, line: str) -> Tuple[str, str]:
+    def split(self, line: str) -> tuple[str, str]:
         r"""
         Split attribute and value.
         Options are stripped.
@@ -219,8 +223,8 @@ class LdifSlapcat:
         """
         while True:
             rlist = [proc.stdout]
-            wlist: List[int] = []
-            xlist: List[int] = []
+            wlist: list[int] = []
+            xlist: list[int] = []
             try:
                 rlist, wlist, xlist = select.select(rlist, wlist, xlist)
                 break
@@ -244,7 +248,7 @@ class LdifSsh(LdifSlapcat):
 
     def __init__(self, hostname: str, ssh: str = 'ssh') -> None:
         super().__init__()
-        self.command = [ssh, hostname] + self.command
+        self.command = [ssh, hostname, *self.command]
 
 
 def __test(_option: Values, _opt_str: str, _value: None, _parser: OptionParser) -> NoReturn:
@@ -254,7 +258,7 @@ def __test(_option: Values, _opt_str: str, _value: None, _parser: OptionParser)
     sys.exit(int(bool(res[0])))
 
 
-def stream2object(ldif: Ldif) -> Dict[str, Entry]:
+def stream2object(ldif: Ldif) -> dict[str, Entry]:
     """
     Convert LDIF stream to dictionary of objects.
 
@@ -264,7 +268,7 @@ def stream2object(ldif: Ldif) -> Dict[str, Entry]:
     >>> stream2object([{'dn': ['dc=test']}])
     {'dc=test': {}}
     """
-    objects: Dict[str, Entry] = {}
+    objects: dict[str, Entry] = {}
     for obj in ldif:
         try:
             dname, = obj.pop('dn')
@@ -276,7 +280,7 @@ def stream2object(ldif: Ldif) -> Dict[str, Entry]:
     return objects
 
 
-def sort_dn(dname: str) -> Tuple[Tuple[str, ...], ...]:
+def sort_dn(dname: str) -> tuple[tuple[str, ...], ...]:
     """
     Sort by reversed dn.
 
@@ -341,7 +345,7 @@ def compare_ldif(lldif: Ldif, rldif: Ldif, options: Values) -> int:
     return ret
 
 
-def compare_keys(ldata: Entry, rdata: Entry) -> Iterator[Tuple[Literal[-1, 0, 1], str, str]]:
+def compare_keys(ldata: Entry, rdata: Entry) -> Iterator[tuple[Literal[-1, 0, 1], str, str]]:
     """
     Compare and return attributes of two LDAP objects.
 
@@ -383,7 +387,7 @@ def compare_keys(ldata: Entry, rdata: Entry) -> Iterator[Tuple[Literal[-1, 0, 1]
             lkey = rkey = ""
 
 
-def compare_values(attr: str, lvalues: List[str], rvalues: List[str]) -> Iterator[Tuple[Literal[-1, 0, 1], str, str]]:
+def compare_values(attr: str, lvalues: list[str], rvalues: list[str]) -> Iterator[tuple[Literal[-1, 0, 1], str, str]]:
     """
     Compare and return values of two multi-valued LDAP attributes.
 
@@ -419,7 +423,7 @@ def compare_values(attr: str, lvalues: List[str], rvalues: List[str]) -> Iterato
             lval = rval = ""
 
 
-def parse_args() -> Tuple[LdifSource, LdifSource, Values]:
+def parse_args() -> tuple[LdifSource, LdifSource, Values]:
     """Parse command line arguments."""
     parser = OptionParser(usage=USAGE, description=DESCRIPTION)
     parser.disable_interspersed_args()
