@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
@@ -31,8 +30,9 @@
 # <https://www.gnu.org/licenses/>.
 
 import subprocess
+import time
+from collections.abc import Generator, Iterator
 from pathlib import Path
-from typing import Dict, Generator, Iterator, List, Union
 
 import pytest
 from playwright.sync_api import Browser, BrowserContext, BrowserType, Page, expect
@@ -58,7 +58,7 @@ def suppress_notifications():
     handler_unset(['umc/web/hooks/suppress_umc_notifications'])
 
 
-phase_report_key = pytest.StashKey[Dict[str, pytest.CollectReport]]()
+phase_report_key = pytest.StashKey[dict[str, pytest.CollectReport]]()
 
 
 @pytest.hookimpl(tryfirst=True, hookwrapper=True)
@@ -180,8 +180,8 @@ def setup_browser_context(context, start_tracing=True):
 @pytest.fixture(scope='module')
 def context_module_scope(
     browser_type: BrowserType,
-    ucs_browser_type_launch_args: Dict,
-    ucs_browser_context_args: Dict,
+    ucs_browser_type_launch_args: dict,
+    ucs_browser_context_args: dict,
 ):
     browser = browser_type.launch(**ucs_browser_type_launch_args)
     return browser.new_context(**ucs_browser_context_args)
@@ -201,8 +201,8 @@ def umc_browser_test_module(
 @pytest.fixture()
 def umc_browser_test(
     browser_type: BrowserType,
-    ucs_browser_type_launch_args: Dict,
-    ucs_browser_context_args: Dict,
+    ucs_browser_type_launch_args: dict,
+    ucs_browser_context_args: dict,
     request: pytest.FixtureRequest,
     kill_module_processes,
     ucr,
@@ -220,7 +220,7 @@ def umc_browser_test(
 def teardown_umc_browser_test(
     request: pytest.FixtureRequest,
     ucr,
-    page: Union[Page, List[Page]],
+    page: Page | list[Page],
     context: BrowserContext,
     browser: Browser,
 ):
@@ -235,10 +235,11 @@ def teardown_umc_browser_test(
         page = [page]
     try:
         if 'call' in report and report['call'].failed:
+            failure_timestamp = time.time_ns()
 
-            save_trace(context, request.node.name, Path('browser').resolve(), ucr)
+            save_trace(context, request.node.name, Path('browser').resolve(), ucr, timestamp=failure_timestamp)
             for i, p in enumerate(page):
-                save_screenshot(p, request.node.name, Path('browser'), ucr, i)
+                save_screenshot(p, request.node.name, Path('browser'), ucr, i, timestamp=failure_timestamp)
                 check_for_backtrace(p, page_index=i)
         else:
             context.tracing.stop()
